"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = require("util");
global.TextEncoder = util_1.TextEncoder;
global.TextDecoder = util_1.TextDecoder;
const inject_1 = require("@furystack/inject");
const core_1 = require("@furystack/core");
const store_manager_helpers_1 = require("./store-manager-helpers");
const mongo_client_factory_1 = require("./mongo-client-factory");
const utils_1 = require("@furystack/utils");
class TestClassWithId {
}
let storeCount = 0;
describe('MongoDB Store', () => {
    let dbIdx = 0;
    const getMongoOptions = (injector) => ({
        injector,
        model: core_1.TestClass,
        primaryKey: 'id',
        collection: `furystack-mongo-store-tests-${storeCount++}`,
        db: `furystack-mongo-store-tests-${dbIdx++}`,
        url: 'mongodb://localhost:27017',
        options: {},
    });
    (0, core_1.createStoreTest)({
        typeName: 'mongodb-store',
        createStore: (i) => {
            const mongoOptions = getMongoOptions(i);
            (0, store_manager_helpers_1.useMongoDb)(mongoOptions);
            const store = i.getInstance(core_1.StoreManager).getStoreFor(core_1.TestClass, 'id');
            const oldDispose = i.dispose;
            i.dispose = async () => {
                const client = await i.getInstance(mongo_client_factory_1.MongoClientFactory).getClientFor(mongoOptions.url, mongoOptions.options);
                const db = client.db(mongoOptions.db);
                await db.dropDatabase();
                oldDispose.call(i);
            };
            return store;
        },
    });
    it('Should retrieve an entity with its id', async () => {
        await (0, utils_1.usingAsync)(new inject_1.Injector(), async (injector) => {
            (0, store_manager_helpers_1.useMongoDb)({ ...getMongoOptions(injector), model: TestClassWithId, primaryKey: '_id' });
            const store = injector.getInstance(core_1.StoreManager).getStoreFor(TestClassWithId, '_id');
            const { created } = await store.add({ value: 'value1' });
            expect(typeof created[0]._id).toBe('string');
            const retrieved = await store.get(created[0]._id);
            expect(retrieved).toEqual(created[0]);
        });
    });
    it('Should retrieve more entities with theis ids', async () => {
        await (0, utils_1.usingAsync)(new inject_1.Injector(), async (injector) => {
            (0, store_manager_helpers_1.useMongoDb)({ ...getMongoOptions(injector), model: TestClassWithId, primaryKey: '_id' });
            const store = injector.getInstance(core_1.StoreManager).getStoreFor(TestClassWithId, '_id');
            const { created } = await store.add({ value: 'value1' }, { value: 'value2' }, { value: 'value3' });
            const retrieved = await store.find({ filter: { _id: { $in: created.map((c) => c._id) } } });
            expect(retrieved.length).toBe(3);
            expect(retrieved).toEqual(created);
        });
    });
});
//# sourceMappingURL=mongodb-store.spec.js.map